#
# spec file for package kdump
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define dracutlibdir %{_prefix}/lib/dracut

%{!?_udevdir: %global _udevdir %(pkg-config --variable=udevdir udev)}
%if "%{_udevdir}" == ""
%if 0%{?suse_version} >= 1230
%global _udevdir /usr/lib/udev
%else
%global _udevdir /lib/udev
%endif
%endif
%define _udevrulesdir %{_udevdir}/rules.d

Url:            https://github.com/ptesarik/kdump

Name:           kdump
Version:        0.8.15
Release:        14.1.11314.0.PTF.936489
Requires:       curl
Requires:       makedumpfile
Requires:       openssh
Summary:        Script for kdump
License:        GPL-2.0+
Group:          System/Kernel
BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  libelf-devel
BuildRequires:  libesmtp-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libssh2-devel
BuildRequires:  libxslt
BuildRequires:  pkg-config
BuildRequires:  udev
BuildRequires:  zlib-devel
#!BuildIgnore:  fop
%if 0%{?suse_version} > 1220
BuildRequires:  systemd
%endif
PreReq:         %insserv_prereq %fillup_prereq
%if 0%{?suse_version} > 1310
PreReq:         dracut
%else
PreReq:         mkinitrd
%endif
Source:         %{name}-%{version}.tar.bz2
Source2:        %{name}-rpmlintrc
Source3:        kdump.service
Patch0:         0001-multipath-Write-proper-regex-into-multipath-conf.patch
Patch1:         %{name}-use-fstab-device.patch
Patch2:         %{name}-count-framebuffer.patch
Patch3:         %{name}-count-const-slabs.patch
Patch4:         %{name}-remove-root-and-resume.patch
Patch5:         %{name}-systemd-support.patch
Patch6:         %{name}-calibrate-systemd-runtime.patch
Patch7:         %{name}-calibrate-systemd-initramfs.patch
Patch8:         %{name}-get-multipath-wwid-from-sysfs.patch
Patch9:         %{name}-split-kdump_default_netdev.patch
Patch10:        %{name}-move-network-setup-to-module-setup.patch
Patch11:        %{name}-add-IPv6-KDUMP_NETCONFIG-modes.patch
Patch12:        %{name}-enable-fadump-ppc64le.patch
Patch13:        %{name}-fadump-bootloader-always.patch
Patch14:        %{name}-bootloader-grub2.patch
Patch15:        %{name}-fadump-keep-sysroot.patch
Patch16:        %{name}-no-xen-secondary-kernel.patch
Patch17:        %{name}-always-pass-kernelver-to-dracut.patch
Patch18:        %{name}-root-parameter.patch
Patch19:        %{name}-device-timeout.patch

Patch905690:    udev-fix.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# rename "kdump-helpers" (10.3) -> "kdump" (11.0/SP2)
Provides:       kdump-helpers = %{version}
Obsoletes:      kdump-helpers < %{version}
# update should detect the split-off from kexec-tools
Provides:       kexec-tools:/etc/init.d/kdump
Requires:       kexec-tools
%if 0%{?suse_version} > 1220
%systemd_requires
%endif
Recommends:     nfs-client cifs-utils
PreReq:         coreutils sed
ExcludeArch:    s390 ppc

%description
kdump is a package that includes several scripts for kdump, including
the init script /etc/init.d/kdump and the configuration file for kdump.

The kernel package and this package are all that are required for a
crash dump to occur. However, if you wish to debug the crash dump
yourself you will need several debugging packages installed for each
kernel flavor and release you wish to debug.

For example, if you are debugging kernel-default, you will need:
- kernel-default-debuginfo
- kernel-default-devel
- kernel-default-devel-debuginfo

These packages are not needed to create the dump and can be installed
after a crash dump has occured.

Authors:
--------
    Bernhard Walle <bwalle@suse.de>

%prep
%setup
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1

%patch905690 -p1

%build
export CFLAGS="%optflags"
export CXXFLAGS="%optflags"
mkdir build
cd build
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} ..
make
cd -

%check
cd build
make test

%install
cd build
make DESTDIR=$RPM_BUILD_ROOT install
cd -
# move udev rules
mkdir -p $RPM_BUILD_ROOT/%{_udevrulesdir}
mv $RPM_BUILD_ROOT/%{_sysconfdir}/udev/rules.d/* $RPM_BUILD_ROOT/%{_udevrulesdir}/
# remove executable bit from non-binaries
chmod -x $RPM_BUILD_ROOT/lib/kdump/setup-kdump.functions
# symlink for init script
mkdir -p $RPM_BUILD_ROOT/sbin
ln -s /etc/init.d/boot.kdump $RPM_BUILD_ROOT/sbin/rckdump
# empty directory
mkdir $RPM_BUILD_ROOT/var/crash
%if 0%{?suse_version} > 1310
rm -r $RPM_BUILD_ROOT/lib/mkinitrd
%endif

%if 0%{?suse_version} > 1220
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -m644 %{S:3} $RPM_BUILD_ROOT%{_unitdir}
%endif

%if 0%{?suse_version} > 1220
%pre
%service_add_pre kdump.service
%endif

%post
# change only permission if the file exists before /etc/sysconfig/kdump
# has been created from /var/adm/fillup-templates/sysconfig.kdump
change_permission=0
if [ ! -f /etc/sysconfig/kdump ] ; then
    change_permission=1
fi
%{fillup_and_insserv -n kdump boot.kdump}
if (( $change_permission )) ; then
    chmod 0600 /etc/sysconfig/kdump
fi
# if /var/log/dump is empty, make it a symlink to /var/crash
if test -d /var/log/dump && rmdir /var/log/dump &>/dev/null ||
        ! test -d /var/log/dump ; then
    ln -snf /var/crash /var/log/dump
fi
%if 0%{?suse_version} > 1220
%service_add_post kdump.service
%endif

%preun
echo "Stopping kdump ..."
%stop_on_removal boot.kdump
%if 0%{?suse_version} > 1220
%service_del_preun kdump.service
%endif

%postun
# force regeneration of kdumprd
touch /etc/sysconfig/kdump
# delete symbolic link
rm /var/log/dump &>/dev/null || true
%restart_on_update boot.kdump
%insserv_cleanup
%if 0%{?suse_version} > 1220
%service_del_postun kdump.service
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README NEWS
%{_sbindir}/kdumptool
%{_sbindir}/mkdumprd
%{_sbindir}/kdump-bootloader.pl
%{_mandir}/man5/kdump.5.gz
%{_mandir}/man7/kdump.7.gz
%{_mandir}/man8/kdumptool.8.gz
%{_mandir}/man8/mkdumprd.8.gz
/sbin/rckdump
%{_sysconfdir}/init.d/boot.kdump
/var/adm/fillup-templates/sysconfig.kdump
%if 0%{?suse_version} <= 1310
/lib/mkinitrd/scripts/*-kdump.sh
/lib/mkinitrd/scripts/setup-kdumpfs.sh
/lib/mkinitrd/scripts/setup-mkdumprd.sh
%endif
%dir %{dracutlibdir}
%dir %{dracutlibdir}/modules.d
%{dracutlibdir}/modules.d/99kdump/
%dir /lib/kdump
/lib/kdump/*
%{_udevrulesdir}/70-kdump.rules
%if 0%{?suse_version} > 1220
%{_unitdir}/kdump.service
%endif

%changelog
* Thu Aug  4 2016 tcech@suse.cz
- fix for bnc#936489
  udev-fix.patch (bnc#905690)
* Thu May 21 2015 ptesarik@suse.cz
- kdump-root-parameter.patch: Add the kdump-root.sh hook to the
  list of installed files (bsc#900134).
- kdump-device-timeout.patch: Refresh.
* Fri May 15 2015 ptesarik@suse.cz
- kdump-device-timeout.patch: Set up device timeout for kdump
  mounts (bsc#909515).
* Fri May 15 2015 ptesarik@suse.cz
- kdump-root-parameter.patch: Make sure system root is not mounted
  in kdump initrd (bsc#900134).
* Tue May 12 2015 ptesarik@suse.cz
- kdump-always-pass-kernelver-to-dracut.patch: Always pass kernel
  version to dracut (bsc#900418).
* Tue May 12 2015 ptesarik@suse.cz
- kdump-no-xen-secondary-kernel.patch: Avoid Xen kernels as kdump
  kernel (bsc#900418).
* Fri Sep 26 2014 ptesarik@suse.cz
- kdump-enable-fadump-ppc64le.patch: Enable FADUMP on ppc64le
  (bsc#889192).
- kdump-fadump-bootloader-always.patch: Always turn on fadump if
  KDUMP_FADUMP is true (bsc#889192).
- kdump-bootloader-grub2.patch: kdump-Bootloader: add support for
  GRUB2 (bsc#889192).
- kdump-fadump-keep-sysroot.patch: Keep /sysroot mount point if
  fadump is on (bsc#889192).
- kdump-get-multipath-wwid-from-sysfs.patch: Refresh.
* Fri Sep 26 2014 ptesarik@suse.cz
- kdump-add-IPv6-KDUMP_NETCONFIG-modes.patch: Refresh: Fix ip
  error messages when KDUMP_NETCONFIG=auto (bnc#885897).
* Tue Sep 23 2014 ptesarik@suse.cz
- kdump-split-kdump_default_netdev.patch: Cleanup: Split
  kdump_default_netdev (bnc#885897).
- kdump-move-network-setup-to-module-setup.patch: Move dracut
  network command line to module-setup.sh (bnc#885897).
- kdump-add-IPv6-KDUMP_NETCONFIG-modes.patch: Add KDUMP_NETCONFIG
  modes to support IPv6 (bnc#885897).
* Mon Sep 22 2014 ptesarik@suse.cz
- kdump-get-multipath-wwid-from-sysfs.patch: Get required multipath
  wwids from sysfs (bnc#883883).
* Thu Sep 18 2014 ptesarik@suse.cz
- kdump-remove-root-and-resume.patch: Remove root= and resume= from
  the kdump kernel command line (bnc#883883).
- kdump-systemd-support.patch: Dracut-systemd support (bnc#883883).
- kdump-calibrate-systemd-runtime.patch: Calibrate: update
  user-space run-time requirements for systemd (bnc#883883).
- kdump-calibrate-systemd-initramfs.patch: Calibrate: update the
  initramfs size (bnc#883883).
* Tue Sep  9 2014 ptesarik@suse.cz
- kdump-count-const-slabs.patch: Add missing addition.
* Mon Sep  8 2014 ptesarik@suse.cz
- kdump-count-const-slabs.patch: Take constant-size slabs into
  account for "kdump calibrate" (bnc#879460).
* Mon Sep  8 2014 ptesarik@suse.cz
- kdump-count-framebuffer.patch: Take framebuffer size into account
  for "kdumptool calibrate" (bnc#879460).
* Fri Sep  5 2014 ptesarik@suse.cz
- kdump-use-fstab-device.patch: Use device from /etc/fstab to mount
  / and /boot (bnc#892451).
* Mon Sep  1 2014 juwolf@suse.com
- Write proper regex into multipath.conf to prevent syntax error there
  (bnc#883883)
  Add: 0001-multipath-Write-proper-regex-into-multipath-conf.patch
* Mon Aug 18 2014 ptesarik@suse.cz
- specfile: Remove call to mkinitrd_setup. With dracut, this is
  completely useless; with mkinitrd, the setup script is run
  automatically after a new mkinitrd script is installed.
* Fri Jul  4 2014 ptesarik@suse.cz
- Switch from mkinitrd to dracut for SLES12 and openSUSE > 13.1.
* Fri Jul  4 2014 ptesarik@suse.cz
- Update to 0.8.15
  o Disable memory cgroup in kdump kernel
  o Limit the number of CPUs on all architectures
  o Increase udevd memory requirements
  o If possible, use wicked to determine network mode
  o Take number of possible CPUs into account for calibrate
- kdump-disable-memory-cgroup.patch: Dropped.
* Mon Jun 16 2014 ptesarik@suse.cz
- kdump-disable-memory-cgroup.patch: disable memory cgroup in the
  kdump kernel (bnc#881091).
* Mon Jun 16 2014 ptesarik@suse.cz
- Update to 0.8.14
  o Disable ACPI memory hotplug in kdump kernel (bnc#881091).
  o Update kernel and initrd estimates
  o Install mount-kdump.sh to dracut module directory (bnc#881851).
- Remove version number from rpmlintrc.
* Fri May 30 2014 ptesarik@suse.cz
- Update to 0.8.13
  o Store current configuration if KDUMP_NETCONFIG is static
    (bnc#876212).
  o Modify kdump udev rules to work with systemd
    (bnc#874992, bnc#809209).
  o Support percent-encoded URLs for KDUMP_SAVEDIR (bnc#869590).
- kdump-fix-udev-rules.patch: Dropped.
- kdump-urldecode.patch: Dropped.
* Tue May 20 2014 ptesarik@suse.cz
- kdump-urldecode.patch: Perform percent decoding on target URL
  (bnc#869590).
* Mon May 19 2014 ptesarik@suse.cz
- kdump-fix-udev-rules.patch: Avoid entering failed state on CPU
  hotplug (bnc#874992, bnc#809209).
* Fri May 16 2014 ptesarik@suse.cz
- Update to 0.8.12
  o Add "ssh" target protocol to transfer the file over the
    standard input to a remote host using the standard ssh client
    (bnc#868704).
  o Prevent double mount of the root file system (bnc#875738).
  o Allow taking remote dumps without mounting any file systems
- specfile: update URL
* Mon May  5 2014 ptesarik@suse.cz
- Update to 0.8.11
  o Use fast xz compression with dracut (bnc#870549)
  o Mount boot/root partition only if needed
  o Copy required programs to the initrd (bnc#874571).
- kdump-0.8.10-dracut-xz-opt.patch: Dropped.
* Tue Apr 15 2014 ptesarik@suse.cz
- kdump-0.8.10-dracut-xz-opt.patch: Use fast xz compression with
  dracut (bnc#870549).
* Fri Mar 28 2014 ptesarik@suse.cz
- specfile cleanup: remove blocks for pre-openSUSE11.0
- fix location of the udev files (see sr 227790).
* Thu Mar 27 2014 ptesarik@suse.cz
- Update to 0.8.10
  o Support snappy compression algorithm (FATE#315726)
  o Improved algorithm for "calibrate"
  o Network support for dracut
  o Filter out DomU pages, when dumping a Xen virtualization host
    (bnc#864910)
  o Do not try to copy separate debuginfo files (bnc#869971)
  o Unit test for FilePath::listDir() (SUSE Test Initiative)
  o delete_dumps: ignore non-kdump directories (FATE#313185)
  o fixed the testsuite on non-x86
- include and run the test suite
- kdump-ledblink-background.patch: Dropped.
- kdump-initrd-network.patch: Dropped.
- kdump-0.8.10-detect-xen-dumps.patch: Dropped.
* Tue Mar 18 2014 ptesarik@suse.cz
- kdump-0.8.9-detect-xen-dumps.patch: fix uninitialized variable;
  without the fix, '-X' is (almost) always added.
* Tue Mar 18 2014 ptesarik@suse.cz
- drop dependency on dracut-network again, because this subpackage
  has been merged with the main dracut package
* Mon Mar 17 2014 ptesarik@suse.cz
- kdump-initrd-network.patch: fix KDUMP_NETCONFIG="auto"
* Mon Mar 17 2014 ptesarik@suse.cz
- add dependency on dracut-network in SLE12 and Factory
- kdump-initrd-network.patch: include dracut 'network' module if
  network is required
* Fri Mar 14 2014 ptesarik@suse.cz
- kdump-0.8.9-detect-xen-dumps.patch: Add '-X' to makedumpfile when
  dumping a Xen host (bnc#864910).
* Fri Mar 14 2014 ptesarik@suse.cz
- kdump-ledblink-background.patch: Run kdumptool in the background.
* Wed Mar  5 2014 juwolf@suse.com
- kdump-initrd-network.patch: Added dracut network activation in
  initrd to mkdumprd.
* Tue Mar  4 2014 juwolf@suse.com
- kdump-ledblink-background.patch: Fixed wrong argument for
  ledblink.
* Sun Mar  2 2014 ptesarik@suse.cz
- %%filelist simplified as suggested by tcech@suse.cz.
* Fri Feb 28 2014 ptesarik@suse.cz
- Update to 0.8.9
  o fix dracut support
  o fix dump save when /boot is not a mount point
- kdumptool_find_kernel.patch: Dropped.
* Fri Feb 28 2014 ptesarik@suse.cz
- Update to 0.8.8
  o dracut support
  o new kdumptool command: calibrate
  o new kdumptool flag: NOSPLIT
  o better support for SMP dumps
- kdump-0.8.7-bsp.patch: Dropped.
- kdump-0.8.7-calibrate.patch: Dropped.
- kdump-0.8.7-nr_cpus.patch: Dropped.
* Fri Feb 14 2014 ptesarik@suse.cz
- kdump-0.8.7-nr_cpus.patch: Use nr_cpus instead of maxcpus with
  recent kernels. (FATE#315725).
- kdump-0.8.7-bsp.patch: Add disable_cpu_apicid for BSP to the
  commandline (bnc#861981).
- kdump-0.8.7-calibrate.patch: Implement kdump memory calibration
  (FATE#315241).
* Fri Feb 14 2014 juwolf@suse.com
- Added patch kdumptool_find_kernel.patch: kdumptool argument order was
  wrong in debug mode
* Fri Jan 24 2014 mpost@suse.com
- Removed s390x from the list of excluded architectures.
* Mon Jan 13 2014 ptesarik@suse.cz
- Update to 0.8.7
  o Change libelf interface to elfutils (libelf1)
  o Fix parsing of command line options
  o New tests
  o Many code cleanups
* Fri Dec  6 2013 ptesarik@suse.cz
- Update to 0.8.6
  o IPv6 support (FATE 316563)
  o unmount filesystems before rebooting kdump environment
* Fri Sep 13 2013 ptesarik@suse.cz
- Update to 0.8.5
  o See NEWS for a complete list of changes.
- kdump.spec: add newly installed files
* Wed Sep  4 2013 fcrozat@suse.com
- Add kdump.service to properly handle kdump initscript with
  systemd.
* Wed Jan  2 2013 ptesarik@suse.cz
- Fix the broken package rename from kdump-helpers.
* Wed Jan  2 2013 ptesarik@suse.cz
- Update to 0.8.2
  o FATE#314283: kdump: log-only mode
  o checking of SSH keys
  o lots of cleanups and bugfixes
- Drop the following patches (included in upstream now):
  o kdump-fix-gcc46.diff
  o kdump-gcc47.patch
  o kdump-save-log
  o kdump-add-none-format
  o kdump-udev-rule
  o kdump-usrmerge.patch
- kdump-format-list: Dropped (wrong).
* Sun Oct  7 2012 crrodriguez@opensuse.org
- Since the /usr merge, the mkinitrd bits are broken
  since tools have changed locations.
- Recommend nfs-client and cifs-utils too.
* Wed Apr 11 2012 jeffm@suse.com.
- kdump: Add 'none' format
- kdump: Allow format to be a list
- kdump: Save dmesg during dump
- kdump: Use correct script location in udev rule
* Sat Mar 17 2012 dimstar@opensuse.org
- Add kdump-gcc47.patch: Fix build with gcc 4.7.
* Sun Jun  5 2011 bernhard@bwalle.de
- Fix build with gcc 4.6.
* Wed Apr 27 2011 jeffm@suse.de
- Updated description to reference packages required for debugging
  (bnc#690194).
* Fri Jan 23 2009 bwalle@suse.de
- Update to 0.8.1
  o Fix invalid syntax in CMakeLists.txt.
  o Fix manpage, the command is called read_ikconfig and not
    print_ikconfig (bnc #468782).
  o Remove the documentation about the non-working network
    configuration in Xen since that has been fixed meanwhile.
  o Make it possible to exit the shell spawned in the initrd with
    'exit' to boot in the kdump system for debugging.
* Wed Jan 14 2009 bwalle@suse.de
- Update to 0.8.0
  o Call asciidoc a2x with -L to fix manual page generation
    problems with asciidoc 8.3.x.
* Thu Dec 11 2008 bwalle@suse.de
- Add BuildIgnore for 'fop' which breaks the Java dependency
  that is not needed for asciidoc generating just manual pages
  (improve build speed).
* Wed Dec  3 2008 bwalle@suse.de
- Update to 0.7.4
  o Don't update bootloader in mkdumprd(8).
- Don't build on s390, s390x and ppc because there is no kdump
  on that architectures.
* Mon Nov 24 2008 bwalle@suse.de
- Update to 0.7.3
  o Document kdump problems on Xen.
  o Don't display the full mkinitrd output.
  o Warn about zero-size vmcore.
  o Default to the auto-detected kernel when mkdumprd is called
    without arguments instead of defaulting to the running kernel.
  o Parse VMCOREINFO_XEN when present with 'read_vmcoreinfo'.
  o Pass the kernel release of the crashed kernel via command line
    in case of Xen.
  o Improve error handling when no crash kernel release is
    available when saving the dump.
* Fri Nov 21 2008 bwalle@suse.de
- Update to 0.7.2
  o Don't use the FQDN but only the hostname to avoid DNS lookups
    and errors on wrongly configured systems (bnc#442830).
  o Fix empty KDUMP_SAVEDIR line when replacing the symbolic link
    with the absolute path.
  o Don't set sysctl kernel.unknown_nmi_panic=1 by default
    (bnc#388736).
  o Mention kernel.panic_on_unrecovered_nmi in the kdump(7)
    manpage.
* Thu Nov 20 2008 bwalle@suse.de
- Update to 0.7.1
  o Document 256M limit on ppc64 for large machines in kdump(7).
* Wed Nov 19 2008 bwalle@suse.de
- Only regenerate the initrd once after update. But make sure that
  it always gets regenerated.
- Update to 0.7.0
  o Add read_ikconfig command.
  o Add find_kernel command in kdumptool, replacing the find code
    in the init script. Needed to prefer the default kernel even
    if the maxcpus kernel (or a realtime kernel) is currently
    booted (bnc#444658).
  o Implement KDUMP_VERBOSE = 16 to debug kdump find_kernel.
  o Make boot.kdump dependent on boot.localnet to have a correct
    hostname (bnc#442830).
  o Fix stripping of the crashkernel command line again
    (bnc#444687).
  o Don't include test cases in the release tarball. They are
    very incomplete and contain too huge test data.
  o Honor TMPDIR and set that to disk space instead of the ramdisk
    when saving the dump in the initrd.
* Thu Nov 13 2008 bwalle@suse.de
- Update to 0.6.7
  o Strip the whole crashkernel option when loading the kdump
    kernel, not only parts of them, also when the extended
    crashkernel syntax has been used.
* Wed Nov 12 2008 bwalle@suse.de
- Update to 0.6.6
  o Fix wrong path when modifying the /etc/sysconfig/kdump file
    when creating the kdump initrd.
  o Prepend a space before MAKEDUMPFILE_OPTIONS so that there's
    always a space between command and the first argument.
  o Fix finding of the kernel image (/boot/vmlinuz) with rootdir.
* Tue Nov 11 2008 bwalle@suse.de
- Update to 0.6.5
  o Fix copying of debug info when --root is specified and the
    debug file resides in GLOBALDEBUGDIR/EXECDIR/DEBUGFILE
    (bnc#443828).
* Tue Nov 11 2008 bwalle@suse.de
- Fix string in %%preun (kexec -> kdump).
- Regenerate the kdump initrd on next startup after the kdump
  package has been updated.
* Sun Nov  2 2008 bwalle@suse.de
- Update to 0.6.4
  o change default location for KDUMP_SAVEDIR to "/var/crash"
  o actually check <version>-kdump before <version>-<flavour> when
    looking for a suitable kdump kernel
  o boot.kdump: Use the full kernel release (obtained with
    /sbin/get_kernel_version) to build the initrd name also when
    symlinks are used (bnc#438218)
  o Assume a default terminal size of 80x25 (for printing the
    horizontal line)
  o Check the exit status of kdumptool
  o Implement support for resolving symbolic links inside a root
    directory (--root=...) when saving the dump. (bnc#431492)
  o Don't print a (red) info message that email failed if both
    KDUMP_SMTP_SERVER and KDUMP_NOTIFICATION_TO are empty.
  o If KDUMP_SAVEDIR points to a local file, resolve symlinks when
    creating the initrd because in theory the file system that
    contains parts of the symlinks is not mounted in initrd.
  o Fix KDUMP_NETCONFIG=auto by calling mkinitrd with right
    parameters.
  o Create core dumps in the initrd when kdumptool crashes.
  o Fix std::logic_error in Email::send() that caused kdumptool to
    terminate unexpectedly.
  o Set the hostname of the SMTP session based on the --fqdn
    parameter.
  o Don't report a failure in the email when there is no one.
- Drop following patches (folded in 0.6.4):
  o kdump-2860e7a5d481633aca345b07db28d95fdb04d649
    Add documentation for "Extended crashkernel commandline"
  o kdump-56814cf5d03dff1d6233de996e79e1dd54cf5144
    boot.kdump: Use the full kernel release for initrd name
  o kdump-8580f201f2f759eb78c646a6b98727b4508101d3
    Reflect 'boot.kdump' in kdump(7)
  o kdump-8712f642965d13539148e385aefb805e3464b62d
    Actually check <version>-kdump before <version>-<flavour> when
    looking for a suitable kdump kernel
  o kdump-f4cf2ef3cc3e6414d7d9386de0ebf7d633cbfed5
    Change default location of KDUMP_SAVEDIR to "/var/crash"
* Tue Oct 28 2008 schwab@suse.de
- Fix %%post failure.
* Sun Oct 26 2008 bwalle@suse.de
- Use the full kernel release (obtained with get_kernel_version)
  to build the initrd name also when symlinks are used
  (bnc#438218).
* Wed Oct 22 2008 bwalle@suse.de
- Actually check <version>-kdump before <version>-<flavour> when
  looking for a suitable kdump kernel.
* Fri Oct 17 2008 bwalle@suse.de
- /etc/sysconfig/kdump should be only readable as root since it
  may contain passwords (bnc#436042).
* Wed Oct 15 2008 bwalle@suse.de
- Reflect 'boot.kdump' in kdump(7).
- Add rpmlintrc: The init script name is correct.
* Mon Oct 13 2008 bwalle@suse.de
- Add documentation for "Extended crashkernel commandline"
  (bnc#430276).
* Wed Sep  3 2008 crrodriguez@suse.de
- use RPM_OPT_FLAGS everywhere [FATE #300498]
* Sat Aug 23 2008 bwalle@suse.de
- /var/crash is now part of the filesystem RPM (removing %%dir)
* Mon Aug 18 2008 bwalle@suse.de
- also create /var/log/dump link when the /var/log/dump directory
  did not exist
- delete /var/log/dump link in %%postun
* Mon Aug 18 2008 bwalle@suse.de
- change default for KDUMP_SAVEDIR to "/var/crash"
* Fri Aug 15 2008 bwalle@suse.de
- update to 0.6.3
  o make the kdump init script a boot script ("boot.kdump")
  o fix init script comments
  o add meta information to manpages
* Tue Aug 12 2008 bwalle@suse.de
- update to 0.6.2
  o correct init script: remove remote FS dependency and also add
    "Should-Stop"
* Sat Aug  9 2008 bwalle@suse.de
- update to 0.6.1
  o add kdump(7) manual page
* Thu Aug  7 2008 bwalle@suse.de
- update to 0.6.0
  o add vmcore(5) manual page
  o implement email support
- use PreReq for mkinitrd instead of BuildRequires
* Mon Aug  4 2008 bwalle@suse.de
- Don't report ELF32 as "invalid ELF class"
* Fri Aug  1 2008 bwalle@suse.de
- update to 0.5.5
  o make dependency to libssh2 optional
* Thu Jul 31 2008 bwalle@suse.de
- update to 0.5.4
  o always create empty ${tmp_mnt}/etc/fstab.kdump
  o change execution state to 'boot'
  o use UUID for fstab.kdump
  o open a shell if something fails and KDUMP_CONTINUE_ON_ERROR is
    true
  o don't include JFS to initrd
  o don't add -s '' parameter to mkinitrd call if the boot splash
    script is not available
  o handle more programs in $KDUMP_REQUIRED_PROGRAMS correct
  o move original /etc/fstab back
- add %%config to udev rule
* Mon Jul 28 2008 bwalle@suse.de
- update to 0.5.3
  o don't exit with error code when the dump directory does not yet
    exist in the 'delete_dumps' command
  o fix syntax error in init/boot-kdump.sh
* Mon Jul 28 2008 bwalle@suse.de
- call mkinitrd_setup in %%post and %%postun
* Mon Jul 28 2008 bwalle@suse.de
- update to 0.5.2
  o copy required programs (KDUMP_REQUIRED_PROGRAMS) in initrd
  o mount dump partition and boot partition in initrd
  o don't exit with error code when the dump directory does not yet
    exist in the 'delete_dumps' command
* Thu Jul 24 2008 bwalle@suse.de
- update to 0.5.1
  o add 'print_target' sub command
  o implement SSH public/private key authentication
* Wed Jul 23 2008 bwalle@suse.de
- update to 0.5.0 (FATE #303043)
  o initrd-based dumping
  o basically rewrite
* Fri Jun 13 2008 bwalle@suse.de
- update to 0.3.4
  o try also $(uname -i) to find the makedumpfile.config in
    /usr/src/linux-${version}-obj/${arch}/${flavour}
  o filter "mem" kernel parameter before loading the kdump kernel
    (bnc#393324)
- delete kdump-clarify-README: merged in new version
- delete kdump-default-nmi: merged in new version
- delete kdump-reload-memory-hotplug: merged in new version
- delete kdump-fix-kernel-detection: merged in new version
* Sun Jun  1 2008 bwalle@suse.de
- set KDUMP_KERNELVER="" on i386 instead of KDUMP_KERNELVER="kdump"
  (with "kdump", the kdump kernel cannot be loaded without manually
  editing the configuration file (bnc#396221)
* Mon May 26 2008 bwalle@suse.de
- fix load of kdump kernel when KDUMP_KERNELVER="kdump" on ppc64
  (bnc#394216)
* Tue May 20 2008 bwalle@suse.de
- fix typo when checking the result of kdump_kernel_loaded
* Mon May 19 2008 bwalle@suse.de
- implement "try-restart" command and use that implementation also
  for "condrestart"
- add udev rules to reload kdump configuration on memory or CPU
  hotplug (bnc#389658)
- set panic_on_unrecovered_nmi only when it exists
* Tue May 13 2008 bwalle@suse.de
- set panic_on_unrecovered_nmi as default (bnc#388736)
* Fri Apr 18 2008 bwalle@suse.de
- clarified README that memory sizes are only recommended values
  (bnc#380577)
* Wed Feb 20 2008 bwalle@suse.de
- use "-o NumberOfPasswordPrompts=0 -o CheckHostIP=no -o
  StrictHostKeyChecking=no" when calling ssh because the user may
  not be able to confirm the questions (bnc#355973)
- require "$network" in init script so than when runlevel 3 is set
  in /etc/sysconfig/kdump, network is available to the kdump
  scripts (bnc#293171)
- update version to 0.2.3
* Sun Jan 13 2008 bwalle@suse.de
- don't add initrd blink stuff for openSUSE <= 10.2 because
  there was no modular initrd script
* Tue Jan  8 2008 bwalle@suse.de
- log the result of kexec call to avoid the impression that loading
  kdump kernel succeeded even if kexec terminated non-zero (350289)
- don't set kernel.panic_on_oops to 1 if kexec failed (350289)
- updated version to 0.3.2
- require kexec-tools
* Wed Dec 12 2007 bwalle@suse.de
- check the disk space afterwards if makedumpfile is used since
  it's not possible to know the dump image size in advance
- updated version to 0.3.1
* Mon Nov 12 2007 tiwai@suse.de
- fix PreReq for insserv and fillup
* Tue Nov  6 2007 bwalle@suse.de
- add "coreutils" and "sed" to PreReq to make rpmlint happy
* Thu Oct 11 2007 bwalle@suse.de
- rename kdump-helpers to kdump
- added GDB helpers, init script and sysconfig file
  (formerly all in the kexec-tools package)
- added README (formerly README.SUSE in the kexec-tools package)
- fix compile warning in src/read-debuglink.c
- log save message to syslog if $KDUMP_VERBOSE & 1 > 0 (#331118)
- improve algorithm for finding the kdump kernel
- updated version to 0.3.0
* Mon Sep  3 2007 bwalle@suse.de
- don't use locking for NFS (#307178)
* Wed Aug 29 2007 bwalle@suse.de
- added Recommends: makedumpfile
* Mon Aug 13 2007 bwalle@suse.de
- run bootloader after modifying initrd
* Fri Jul 27 2007 bwalle@suse.de
- update to 0.2.4 (#302257)
  o implement KDUMP_KEEP_OLD_DUMPS = -2 for deleting all dumps
    (except the latest, which is saved afterwards
* Mon Jul  2 2007 tiwai@suse.de
- changed from libelf to libelf0-devel in buildrequires.
* Mon Jun 18 2007 bwalle@suse.de
- update to 0.2.3
  o fixed read-debuglink
  o changed NFS URL, no separation between share and directory
  o added kdump-led_blink to blink LEDs (for broken VGA console)
  o added mkinitrd script (for blink) and /sbin/mkinitrd to
    %%postin and %%postun
* Mon Jun 11 2007 bwalle@suse.de
- update to 0.2.2
  o add read-debuglink
* Sun Jun 10 2007 bwalle@suse.de
- update to 0.2.1
  o add manpages for all programs
* Mon May 28 2007 bwalle@suse.de
- first version
